@@ -1,26 +1,20 @@
-/*  Audacious - Cross-platform multimedia player
- *  Copyright (C) 2005-2011  Audacious development team
+/*
+ * pluginenum.c
+ * Copyright 2007-2011 William Pitcock and John Lindgren
  *
- *  Based on BMP:
- *  Copyright (C) 2003-2004  BMP development team
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
  *
- *  Based on XMMS:
- *  Copyright (C) 1998-2003  XMMS development team
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions, and the following disclaimer.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; under version 3 of the License.
+ * 2. Redistributions in binary form must reproduce the above copyright notice,
+ *    this list of conditions, and the following disclaimer in the documentation
+ *    provided with the distribution.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses>.
- *
- *  The Audacious team does not consider modular code linking to
- *  Audacious or using our public API to be a derived work.
+ * This software is provided "as is" and without any warranty, express or
+ * implied. In no event shall the authors be liable for any damages arising from
+ * the use of this software.
  */
 
 #include <assert.h>
@@ -33,13 +27,8 @@
 
 #include "config.h"
 
-#ifndef SHARED_SUFFIX
-# define SHARED_SUFFIX G_MODULE_SUFFIX
-#endif
-
 #include "debug.h"
 #include "plugin.h"
-#include "ui_preferences.h"
 #include "util.h"
 
 #define AUD_API_DECLARE
@@ -119,8 +108,6 @@ static void plugin2_unload (LoadedModule * loaded)
     case PLUGIN_TYPE_PLAYLIST:
     case PLUGIN_TYPE_INPUT:
     case PLUGIN_TYPE_EFFECT:
-        if (PLUGIN_HAS_FUNC (header, settings))
-            plugin_preferences_cleanup (header->settings);
         if (PLUGIN_HAS_FUNC (header, cleanup))
             header->cleanup ();
         break;
@@ -160,9 +147,9 @@ void plugin_load (const char * filename)
     g_module_close(module);
 }
 
-static bool_t scan_plugin_func(const char * path, const char * basename, gpointer data)
+static bool_t scan_plugin_func(const char * path, const char * basename, void * data)
 {
-    if (!str_has_suffix_nocase(basename, SHARED_SUFFIX))
+    if (!str_has_suffix_nocase(basename, PLUGIN_SUFFIX))
         return FALSE;
 
     if (!g_file_test(path, G_FILE_TEST_IS_REGULAR))
